@@ -7,11 +7,12 @@
   /* NQS license information */
 #include <nqs_generic/debug.h>
   /* debugging support */
+#include <nqs_generic/proto.h>
+  /* ANSI C prototypes */
 #include <time.h>
 #include <stdio.h>
 
 extern char *tzname [2];
-extern void tzset();
   /* Set local timezone */
 
 /* 
